Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.PersonVersandartSchlank Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.PersonVersandartSchlank einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.PersonVersandartSchlank) | Gemeinde_Modelle.PersonVersandartSchlank |
__str__(self) (Definiert in Gemeinde_Modelle.PersonVersandartSchlank) | Gemeinde_Modelle.PersonVersandartSchlank |
keyFeldNavi (Definiert in Gemeinde_Modelle.PersonVersandartSchlank) | Gemeinde_Modelle.PersonVersandartSchlank | static
R_person (Definiert in Gemeinde_Modelle.PersonVersandartSchlank) | Gemeinde_Modelle.PersonVersandartSchlank | static
R_versandart (Definiert in Gemeinde_Modelle.PersonVersandartSchlank) | Gemeinde_Modelle.PersonVersandartSchlank | static